# Generated by Django 2.2.9 on 2020-02-26 09:51

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='ExchangeRates',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('usd', models.FloatField(default=1, verbose_name='USD')),
                ('eur', models.FloatField(default=1, verbose_name='EUR')),
                ('usd_eur', models.FloatField(default=1, verbose_name='USD - EUR')),
            ],
            options={
                'verbose_name': 'Exchange rates',
                'verbose_name_plural': 'Exchange rates',
            },
        ),
    ]
